library(plyr)
library(dplyr)
library(MPDiR)
library(quickpsy)
library(fitdistrplus)
library(ggplot2)



remove(list = ls())
defaultpath <- "D:/r-scripts/"

setwd(defaultpath)
source("plotStairCases.R")

setwd("exp-data/")
#setwd("exp-data_random/")
file_list <- list.files()
show(file_list)

setwd(defaultpath)

if (exists ("allThresholds")) { rm(allThresholds) }

problemParticipant <- c()
problemCondition <- c()
problemDescription <- c()

# basic loop that reads over participant staircases
# and computes thresholds per participant, vis, elements
for (file in file_list){

  print(file)
  
  setwd("exp-data/")
  #setwd("exp-data_random/")
  dataFile <- read.csv(file)


  setwd(defaultpath)
  
  # calculate reversals: keep reversal trials (reversal == 1), keep after the 2nd reversal (count > 2), keep non training trials (trial > 0)
  tmp <- dataFile
  tmp <- dataFile [ which (dataFile$reversal == 1 & dataFile$count > 2 & dataFile$trial > 0),] # keep after the 2nd reversal 

  statstable <- tmp
  statstable <- ddply(tmp,
                      c("participant","chart", "elements"),
                      summarise,
                      threshold=mean(time)
   )
  
  # this is a bit dirty, but fast...
  charts <- c('donut','bar','radial')
  sizes <- c(7,12,24)
  

  
  for(c in charts)
  {
    for(s in sizes)
    {
      dfSize7 <- subset(dataFile,elements == s & chart == c)#dataFile[which(dataFile$elements == s & as.character(dataFile$dataFile$chart)==as.character(c)),]

      #we don't have 3 reversals      
      if(nrow(dfSize7[ which (dfSize7$reversal == 1 & dfSize7$count == 3 & dfSize7$trial > 0),]) == 0){
        problemParticipant <- c(problemParticipant,file)
        problemCondition <- c(problemCondition,paste(c,".",s))
        problemDescription <- c(problemDescription,"<3 reversals")
      }
      else
      {
        maxReversal <- max(dfSize7$count,na.rm=TRUE)
        maxTrial <- max(dfSize7$trial,na.rm=TRUE)
        
        if(maxReversal < 15 & maxTrial <150)
        {
          problemParticipant <- c(problemParticipant,file)
          problemCondition <- c(problemCondition,paste(c,".",s))
          problemDescription <- c(problemDescription,"early termination")
        }
      }
    }
  }
  
  
   mydata <- dataFile[which (dataFile$trial > 0),] # no training
   mydata <- mydata[order(mydata$participant, mydata$chart, mydata$elements),] # order before join
   statstable <- statstable[order(statstable$participant, statstable$chart, statstable$elements),] # order before join
   mydatawithstats <- join (mydata,statstable) # join by = c("participant","chart","elemenents")) to add the threshold for plotting purposes
   
   start_stair <- subset(dataFile,count==3)
   start_stair$start <- start_stair$trial
   mydatawithstats <- join (mydatawithstats,start_stair)
   
   # plotting, can remove if needed (missing value errors are because points are beyond plot dimensions - check plotStairCases)
   tmp_table <- ddply(mydatawithstats,
                      c("participant","chart", "elements"),
                      summarise,
                      start = max(mydatawithstats$start,na.rm = TRUE),
                      tmp_var = plotStaircases(mydatawithstats),
                      tmp_var = plotLogStaircases(mydatawithstats) #add back if you want plots in a log scale for time 
   )
   
   
  
  if ( !exists("allThresholds") ){
    allThresholds <- statstable
  } else {
    allThresholds <- rbind(allThresholds,statstable)
    }
  

}

write.csv(data.frame(problemParticipant,problemCondition,problemDescription), file="problems.csv")
#write.csv(data.frame(problemParticipant,problemCondition,problemDescription), file="problems_random.csv")

setwd(defaultpath)
write.csv(allThresholds, file="thresholds.csv")
#write.csv(allThresholds, file="thresholds_random.csv")


