library(plyr)
library(dplyr)
library(MPDiR)
library(quickpsy)
library(fitdistrplus)
library(ggplot2)



remove(list = ls())
defaultpath <- "D:/r-scripts/"

setwd(defaultpath)

setwd("exp-data/")
file_list <- list.files()
show(file_list)

setwd(defaultpath)

if (exists ("allData")) { rm(allData) }

problemParticipant <- c()
problemCondition <- c()
problemDescription <- c()

# basic loop that reads over participant staircases
# and computes thresholds per participant, vis, elements
for (file in file_list){

  print(file)
  
  setwd("exp-data/")
  dataFile <- read.csv(file)

  setwd(defaultpath)
  
  # collect all trials in order to calculate error rate, keep non training trials (trial > 0)
  tmp <- dataFile
  tmp <- dataFile [ which (dataFile$trial > 0),] # no training

  charts <- c('donut','bar','radial')
  sizes <- c(7,12,24)

  for(c in charts)
  {
    for(s in sizes)
    {
      dfSize7 <- subset(dataFile,elements == s & chart == c)#dataFile[which(dataFile$elements == s & as.character(dataFile$dataFile$chart)==as.character(c)),]

      #we don't have 3 reversals      
      if(nrow(dfSize7[ which (dfSize7$reversal == 1 & dfSize7$count == 3 & dfSize7$trial > 0),]) == 0){
        problemParticipant <- c(problemParticipant,file)
        problemCondition <- c(problemCondition,paste(c,".",s))
        problemDescription <- c(problemDescription,"<3 reversals")
      }
      else
      {
        maxReversal <- max(dfSize7$count,na.rm=TRUE)
        maxTrial <- max(dfSize7$trial,na.rm=TRUE)
        
        if(maxReversal < 15 & maxTrial <150)
        {
          problemParticipant <- c(problemParticipant,file)
          problemCondition <- c(problemCondition,paste(c,".",s))
          problemDescription <- c(problemDescription,"early termination")
        }
      }
    }
  }

  if ( !exists("allData") ){
    allData <- dataFile
  } else {
    allData <- rbind(allData,tmp)
    }
}

allData$error <- 0
allData$error[allData$answer == "error"] <- 1

errors_table <- ddply(allData,
                   c("chart", "elements"),
                   summarise,
                   mean_err = mean(error)
)

write.csv(errors_table, file="error_table.csv")





