library(plyr)

source("CI-Functions.R")
source("calculateThresholdReversals")
setwd(defaultpath)

mydata <- read.table("thresholds.csv", header=T, sep=",")
#mydata <- read.table("thresholds_random.csv", header=T, sep=",")

# create unique technique name
mydata$condition <- paste(mydata$chart, ".", mydata$elements, sep="") 


#############
# bars only
#############

# order for the transpose
chart_bar <- mydata [ which (mydata$chart=="bar"),]
chart_bar <- chart_bar [ order(chart_bar$participant, chart_bar$chart, chart_bar$elements), ]
#
myvars <- c("participant", "condition", "threshold")
chart_bar <- chart_bar [myvars]
#
chart_bar <- reshape(chart_bar, timevar="condition", idvar=c("participant"), direction="wide")
colnames(chart_bar) <- gsub("threshold.", "", colnames(chart_bar))


#############
# bars only analysis
#############

data <- chart_bar
#data <- aggregate(data,by=list(data$participant), FUN=mean, na.rm=TRUE)

techniqueA <- bootstrapMeanCI(data$bar.7)
techniqueB <- bootstrapMeanCI(data$bar.12)
techniqueC <- bootstrapMeanCI(data$bar.24)

analysisData <- c()
analysisData$name <- c("bar.24","bar.12","bar.7")
analysisData$pointEstimate <- c(techniqueC[1], techniqueB[1], techniqueA[1])
analysisData$ci.max <- c(techniqueC[3], techniqueB[3], techniqueA[3])
analysisData$ci.min <- c(techniqueC[2], techniqueB[2], techniqueA[2])

datatoprint <- data.frame(factor(analysisData$name),analysisData$pointEstimate, analysisData$ci.max, analysisData$ci.min)
colnames(datatoprint) <- c("technique", "mean_time", "lowerBound_CI", "upperBound_CI ") #We use the name mean_time for the value of the mean even though it's not a time, it's just to parse the data for the plot
barChart(datatoprint,analysisData$name ,nbTechs = 3, ymin = -1000, ymax = 10000, "", "Precision. Error Bars, 95% CIs")

ggsave("plots/charts_bar_CI-means.pdf", width=8, height=2)
#ggsave("plots_random/charts_bar_CI-means.pdf", width=8, height=2)

### means

diffAB = bootstrapMeanCI(data$bar.7 - data$bar.12)
diffCB = bootstrapMeanCI(data$bar.24 - data$bar.12)
diffCA = bootstrapMeanCI(data$bar.24 - data$bar.7)

analysisData <- c()
analysisData$name <- c("bar.24 - bar.7","bar.24 - bar.12","bar.7 - bar.12")
analysisData$pointEstimate <- c(diffCA[1], diffCB[1], diffAB[1])
analysisData$ci.max <- c(diffCA[3], diffCB[3], diffAB[3])
analysisData$ci.min <- c(diffCA[2], diffCB[2], diffAB[2])

datatoprint <- data.frame(factor(analysisData$name),analysisData$pointEstimate, analysisData$ci.max, analysisData$ci.min)
colnames(datatoprint) <- c("technique", "mean_time", "lowerBound_CI", "upperBound_CI ") #We use the name mean_time for the value of the mean even though it's not a time, it's just to parse the data for the plot
barChart(datatoprint,analysisData$name ,nbTechs = 3, ymin = -1000, ymax = 10000, "", "Time. Error Bars, 95% CIs")

ggsave("plots/charts_bar_CI-diffs.pdf", width=8, height=2)
#ggsave("plots_random/charts_bar_CI-diffs.pdf", width=8, height=2)


