library(plyr)

source("CI-Functions.R")
source("calculateThresholdReversals")
setwd(defaultpath)


mydata <- read.table("thresholds.csv", header=T, sep=",")
#mydata <- read.table("thresholds_random.csv", header=T, sep=",")

# create unique technique name
mydata$condition <- paste(mydata$chart, ".", mydata$elements, sep="") 


#############
# donuts only
#############

# order for the transpose
chart_donut <- mydata [ which (mydata$chart=="donut"),]
chart_donut <- chart_donut [ order(chart_donut$participant, chart_donut$chart, chart_donut$elements), ]
#
myvars <- c("participant", "condition", "threshold")
chart_donut <- chart_donut [myvars]
#
chart_donut <- reshape(chart_donut, timevar="condition", idvar=c("participant"), direction="wide")
colnames(chart_donut) <- gsub("threshold.", "", colnames(chart_donut))


#############
# donuts only analysis
#############

data <- chart_donut
#data <- aggregate(data,by=list(data$participant), FUN=mean, na.rm=TRUE)

techniqueA <- bootstrapMeanCI(data$donut.7)
techniqueB <- bootstrapMeanCI(data$donut.12)
techniqueC <- bootstrapMeanCI(data$donut.24)

analysisData <- c()
analysisData$name <- c("donut.24","donut.12","donut.7")
analysisData$pointEstimate <- c(techniqueC[1], techniqueB[1], techniqueA[1])
analysisData$ci.max <- c(techniqueC[3], techniqueB[3], techniqueA[3])
analysisData$ci.min <- c(techniqueC[2], techniqueB[2], techniqueA[2])

datatoprint <- data.frame(factor(analysisData$name),analysisData$pointEstimate, analysisData$ci.max, analysisData$ci.min)
colnames(datatoprint) <- c("technique", "mean_time", "lowerBound_CI", "upperBound_CI ") #We use the name mean_time for the value of the mean even though it's not a time, it's just to parse the data for the plot
barChart(datatoprint,analysisData$name ,nbTechs = 3, ymin = -1000, ymax = 10000, "", "Precision. Error donuts, 95% CIs")

ggsave("plots/charts_donut_CI-means.pdf", width=8, height=2)
#ggsave("plots_random/charts_donut_CI-means.pdf", width=8, height=2)

### means

diffAB = bootstrapMeanCI(data$donut.7 - data$donut.12)
diffCB = bootstrapMeanCI(data$donut.24 - data$donut.12)
diffCA = bootstrapMeanCI(data$donut.24 - data$donut.7)


analysisData <- c()
analysisData$name <- c("donut.24 - donut.7","donut.24 - donut.12","donut.7 - donut.12")
analysisData$pointEstimate <- c(diffCA[1], diffCB[1], diffAB[1])
analysisData$ci.max <- c(diffCA[3], diffCB[3], diffAB[3])
analysisData$ci.min <- c(diffCA[2], diffCB[2], diffAB[2])

datatoprint <- data.frame(factor(analysisData$name),analysisData$pointEstimate, analysisData$ci.max, analysisData$ci.min)
colnames(datatoprint) <- c("technique", "mean_time", "lowerBound_CI", "upperBound_CI ") #We use the name mean_time for the value of the mean even though it's not a time, it's just to parse the data for the plot
barChart(datatoprint,analysisData$name ,nbTechs = 3, ymin = -1000, ymax = 10000, "", "Time. Error donuts, 95% CIs")

ggsave("plots/charts_donut_CI-diffs.pdf", width=8, height=2)
#ggsave("plots_random/charts_donut_CI-diffs.pdf", width=8, height=2)



