library(plyr)

#source("CI-Functions.R")
source("CI-Functions-Bonferroni.R")
#source("calculateThresholdReversals")
defaultpath <- "D:/r-scripts/"
setwd(defaultpath)


mydata <- read.table("thresholds.csv", header=T, sep=",")
mydata <- read.table("thresholds_random.csv", header=T, sep=",")

# create unique technique name
mydata$condition <- paste(mydata$chart, ".", mydata$elements, sep="") 


#############
# elements 24
#############

# order for the transpose
elements_24 <- mydata [ which (mydata$elements==24),]
elements_24 <- elements_24 [ order(elements_24$participant, elements_24$chart, elements_24$elements), ]
#
myvars <- c("participant", "condition", "threshold")
elements_24 <- elements_24 [myvars]
#
elements_24 <- reshape(elements_24, timevar="condition", idvar=c("participant"), direction="wide")
colnames(elements_24) <- gsub("threshold.", "", colnames(elements_24))


#############
# elements 24 analysis
#############

data <- elements_24
#data <- aggregate(data,by=list(data$participant), FUN=mean, na.rm=TRUE)

techniqueA <- bootstrapMeanCI(data$bar.24)
techniqueB <- bootstrapMeanCI(data$donut.24)
techniqueC <- bootstrapMeanCI(data$radial.24)

analysisData <- c()
analysisData$name <- c("radial.24","donut.24","bar.24")
analysisData$pointEstimate <- c(techniqueC[1], techniqueB[1], techniqueA[1])
analysisData$ci.max <- c(techniqueC[3], techniqueB[3], techniqueA[3])
analysisData$ci.min <- c(techniqueC[2], techniqueB[2], techniqueA[2])

datatoprint <- data.frame(factor(analysisData$name),analysisData$pointEstimate, analysisData$ci.max, analysisData$ci.min)
colnames(datatoprint) <- c("technique", "mean_time", "lowerBound_CI", "upperBound_CI ") #We use the name mean_time for the value of the mean even though it's not a time, it's just to parse the data for the plot
barChart(datatoprint,analysisData$name ,nbTechs = 3, ymin = 0, ymax = 5000, "", "")

ggsave("plots/elements_24_CI-means.pdf", width=8, height=2)
#ggsave("plots_random/elements_24_CI-means.pdf", width=8, height=2)

### means

## CI 95%
#
# diffAB = bootstrapMeanCI(data$bar.24-data$donut.24)
# diffCB = bootstrapMeanCI(data$radial.24 - data$donut.24)
# diffCA = bootstrapMeanCI(data$radial.24 - data$bar.24)
# 
# analysisData <- c()
# analysisData$name <- c("radial.24 - bar.24","radial.24 - donut.24","bar.24 - donut.24")
# analysisData$pointEstimate <- c(diffCA[1], diffCB[1], diffAB[1])
# analysisData$ci.max <- c(diffCA[3], diffCB[3], diffAB[3])
# analysisData$ci.min <- c(diffCA[2], diffCB[2], diffAB[2])
# 
# datatoprint <- data.frame(factor(analysisData$name),analysisData$pointEstimate, analysisData$ci.max, analysisData$ci.min)
# colnames(datatoprint) <- c("technique", "mean_time", "lowerBound_CI", "upperBound_CI ") #We use the name mean_time for the value of the mean even though it's not a time, it's just to parse the data for the plot
# barChart(datatoprint,analysisData$name ,nbTechs = 3, ymin = 0, ymax = 5000, "", "")
# 
# ggsave("plots/elements_24_CI-diffs.pdf", width=8, height= 2)

# CIs with adapted alpha value for multiple comparisons

diffAB = bootstrapMeanCI_corr(data$bar.24-data$donut.24, 9)
diffCB = bootstrapMeanCI_corr(data$radial.24 - data$donut.24, 9)
diffCA = bootstrapMeanCI_corr(data$radial.24 - data$bar.24, 9)

analysisData <- c()
analysisData$name <- c("radial.24 - bar.24","radial.24 - donut.24","bar.24 - donut.24")
analysisData$pointEstimate <- c(diffCA[1], diffCB[1], diffAB[1])
analysisData$ci.max <- c(diffCA[3], diffCB[3], diffAB[3])
analysisData$ci.min <- c(diffCA[2], diffCB[2], diffAB[2])
analysisData$level <- c(diffCA[4], diffCB[4], diffAB[4])
analysisData$ci_corr.max <- c(diffCA[6], diffCB[6], diffAB[6])
analysisData$ci_corr.min <- c(diffCA[5], diffCB[5], diffAB[5])

datatoprint <- data.frame(factor(analysisData$name), analysisData$pointEstimate, analysisData$ci.max, analysisData$ci.min, analysisData$level, analysisData$ci_corr.max, analysisData$ci_corr.min)
colnames(datatoprint) <- c("technique", "mean_time", "lowerBound_CI", "upperBound_CI", "corrected_CI", "lowerBound_CI_corr", "upperBound_CI_corr") #We use the name mean_time for the value of the mean even though it's not a time, it's just to parse the data for the plot
barChart_corr(datatoprint, analysisData$name, nbTechs = 3, ymin = -50, ymax = 5000, "", "")

ggsave("plots/elements_24_CI-diffs_corr.pdf", width=8, height= 2)
#ggsave("plots_random/elements_24_CI-diffs_corr.pdf", width=8, height= 2)
