library(plyr)

#source("CI-Functions.R")
source("CI-Functions-Bonferroni.R")
#source("calculateThresholdReversals")
defaultpath <- "D:/r-scripts/"
setwd(defaultpath)

mydata <- read.table("thresholds.csv", header=T, sep=",")
#mydata <- read.table("thresholds_random.csv", header=T, sep=",")

# create unique technique name
mydata$condition <- paste(mydata$chart, ".", mydata$elements, sep="") 


#############
# elements 7
#############

# order for the transpose
elements_7 <- mydata [ which (mydata$elements==7),]
elements_7 <- elements_7 [ order(elements_7$participant, elements_7$chart, elements_7$elements), ]
#
myvars <- c("participant", "condition", "threshold")
elements_7 <- elements_7 [myvars]
#
elements_7 <- reshape(elements_7, timevar="condition", idvar=c("participant"), direction="wide")
colnames(elements_7) <- gsub("threshold.", "", colnames(elements_7))


#############
# elements 7 analysis
#############

data <- elements_7
#data <- aggregate(data,by=list(data$participant), FUN=mean, na.rm=TRUE)

techniqueA <- bootstrapMeanCI(data$bar.7)
techniqueB <- bootstrapMeanCI(data$donut.7)
techniqueC <- bootstrapMeanCI(data$radial.7)

analysisData <- c()
analysisData$name <- c("radial.7","donut.7","bar.7")
analysisData$pointEstimate <- c(techniqueC[1], techniqueB[1], techniqueA[1])
analysisData$ci.max <- c(techniqueC[3], techniqueB[3], techniqueA[3])
analysisData$ci.min <- c(techniqueC[2], techniqueB[2], techniqueA[2])

datatoprint <- data.frame(factor(analysisData$name),analysisData$pointEstimate, analysisData$ci.min, analysisData$ci.max)
colnames(datatoprint) <- c("technique", "mean_time", "lowerBound_CI", "upperBound_CI ") #We use the name mean_time for the value of the mean even though it's not a time, it's just to parse the data for the plot
barChart(datatoprint,analysisData$name ,nbTechs = 3, ymin = 0, ymax = 5000, "", "")

ggsave("plots/elements_7_CI-means.pdf", width=8, height=2)
#ggsave("plots_random/elements_7_CI-means.pdf", width=8, height=2)

### means

## CIs 95%

# diffAB = bootstrapMeanCI(data$bar.7 - data$donut.7)
# diffCB = bootstrapMeanCI(data$radial.7 - data$donut.7)
# diffCA = bootstrapMeanCI(data$radial.7 - data$bar.7)
# 
# analysisData <- c()
# analysisData$name <- c("radial.7 - bar.7","radial.7 - donut.7","bar.7 - donut.7")
# analysisData$pointEstimate <- c(diffCA[1], diffCB[1], diffAB[1])
# analysisData$ci.max <- c(diffCA[3], diffCB[3], diffAB[3])
# analysisData$ci.min <- c(diffCA[2], diffCB[2], diffAB[2])
# 
# datatoprint <- data.frame(factor(analysisData$name),analysisData$pointEstimate, analysisData$ci.max, analysisData$ci.min)
# colnames(datatoprint) <- c("technique", "mean_time", "lowerBound_CI", "upperBound_CI") #We use the name mean_time for the value of the mean even though it's not a time, it's just to parse the data for the plot
# barChart(datatoprint,analysisData$name ,nbTechs = 3, ymin = 0, ymax = 5000, "", "")
# 
# ggsave("plots_random/elements_7_CI-diffs.pdf", width=8, height= 2)


# CIs with adapted alpha value for multiple comparisons

diffAB = bootstrapMeanCI_corr(data$bar.7 - data$donut.7, 9)
diffCB = bootstrapMeanCI_corr(data$radial.7 - data$donut.7, 9)
diffCA = bootstrapMeanCI_corr(data$radial.7 - data$bar.7, 9)

analysisData <- c()
analysisData$name <- c("radial.7 - bar.7","radial.7 - donut.7","bar.7 - donut.7")
analysisData$pointEstimate <- c(diffCA[1], diffCB[1], diffAB[1])
analysisData$ci.max <- c(diffCA[3], diffCB[3], diffAB[3])
analysisData$ci.min <- c(diffCA[2], diffCB[2], diffAB[2])
analysisData$level <- c(diffCA[4], diffCB[4], diffAB[4])
analysisData$ci_corr.max <- c(diffCA[6], diffCB[6], diffAB[6])
analysisData$ci_corr.min <- c(diffCA[5], diffCB[5], diffAB[5])

datatoprint <- data.frame(factor(analysisData$name), analysisData$pointEstimate, analysisData$ci.max, analysisData$ci.min, analysisData$level, analysisData$ci_corr.max, analysisData$ci_corr.min)
colnames(datatoprint) <- c("technique", "mean_time", "lowerBound_CI", "upperBound_CI", "corrected_CI", "lowerBound_CI_corr", "upperBound_CI_corr") #We use the name mean_time for the value of the mean even though it's not a time, it's just to parse the data for the plot
barChart_corr(datatoprint, analysisData$name, nbTechs = 3, ymin = -50, ymax = 5000, "", "")
 
ggsave("plots/elements_7_CI-diffs_corr.pdf", width=8, height= 2)
#ggsave("plots_random/elements_7_CI-diffs_corr.pdf", width=8, height= 2)
 



